@@ -14,16 +14,14 @@
 import gc
 import unittest
 
-from persistent.interfaces import UPTODATE
 from persistent._compat import PYPY
+from persistent.interfaces import UPTODATE
 from persistent.tests.utils import skipIfNoCExtension
 
 
-# pylint:disable=protected-access,too-many-lines,too-many-public-methods
-# pylint:disable=attribute-defined-outside-init,redefined-outer-name
-
 _marker = object()
 
+
 class DummyPersistent:
     _Persistent__ring = None
 
@@ -48,12 +46,13 @@ class ClosedConnection(DummyConnection):
     def __init__(self, test):
         self.test = test
 
-    def setstate(self, obj): # pragma: no cover
+    def setstate(self, obj):  # pragma: no cover
         self.test.fail("Connection is closed")
 
     def register(self, obj):
         """Does nothing."""
 
+
 def _len(seq):
     return len(list(seq))
 
@@ -62,8 +61,10 @@ class PickleCacheTestMixin:
 
     def _getTargetClass(self):
         from persistent.picklecache import PickleCachePy as BasePickleCache
+
         class PickleCache(BasePickleCache):
-            _CACHEABLE_TYPES = BasePickleCache._CACHEABLE_TYPES + (DummyPersistent,)
+            _CACHEABLE_TYPES = BasePickleCache._CACHEABLE_TYPES + \
+                (DummyPersistent,)
         return PickleCache
 
     def _getTargetInterface(self):
@@ -188,7 +189,6 @@ class PickleCacheTestMixin:
         with self.assertRaises(ValueError):
             cache[KEY] = uptodate
 
-
     def test___setitem___non_ghost(self):
         KEY = b'uptodate'
         cache = self._makeOne()
@@ -202,13 +202,14 @@ class PickleCacheTestMixin:
         self.assertEqual(_len(cache.klass_items()), 0)
         self.assertEqual(items[0][0], KEY)
         self.assertEqual(cache.ringlen(), 1)
-        self.assertTrue(items[0][1] is uptodate)
-        self.assertTrue(cache[KEY] is uptodate)
-        self.assertTrue(cache.get(KEY) is uptodate)
+        self.assertIs(items[0][1], uptodate)
+        self.assertIs(cache[KEY], uptodate)
+        self.assertIs(cache.get(KEY), uptodate)
 
     def test___setitem___persistent_class(self):
 
         KEY = b'pclass'
+
         class pclass:
             _p_oid = KEY
             _p_jar = DummyConnection()
@@ -242,6 +243,7 @@ class PickleCacheTestMixin:
 
         KEY = b'pclass'
         cache = self._makeOne()
+
         class pclass:
             _p_oid = KEY
             _p_jar = DummyConnection()
@@ -261,7 +263,7 @@ class PickleCacheTestMixin:
         cache[KEY] = uptodate
 
         del cache[KEY]
-        self.assertTrue(cache.get(KEY, self) is self)
+        self.assertIs(cache.get(KEY, self), self)
 
     def test___delitem___w_ghost(self):
         from persistent.interfaces import GHOST
@@ -273,7 +275,7 @@ class PickleCacheTestMixin:
         cache[KEY] = ghost
 
         del cache[KEY]
-        self.assertTrue(cache.get(KEY, self) is self)
+        self.assertIs(cache.get(KEY, self), self)
 
     def test___delitem___w_remaining_object(self):
         cache = self._makeOne()
@@ -286,8 +288,8 @@ class PickleCacheTestMixin:
         cache[UPTODATE] = uptodate
 
         del cache[UPTODATE]
-        self.assertTrue(cache.get(UPTODATE, self) is self)
-        self.assertTrue(cache.get(REMAINS, self) is remains)
+        self.assertIs(cache.get(UPTODATE, self), self)
+        self.assertIs(cache.get(REMAINS, self), remains)
 
     def test_lruitems(self):
         cache = self._makeOne()
@@ -304,7 +306,6 @@ class PickleCacheTestMixin:
         self.assertEqual(items[1][0], TWO)
         self.assertEqual(items[2][0], THREE)
 
-
     def _numbered_oid(self, i):
         return b'oid_%04d' % i
 
@@ -326,7 +327,7 @@ class PickleCacheTestMixin:
         self.assertEqual(cache.cache_non_ghost_count, 100)
 
         cache.incrgc()
-        gc.collect() # banish the ghosts who are no longer in the ring
+        gc.collect()  # banish the ghosts who are no longer in the ring
 
         self.assertEqual(cache.cache_non_ghost_count, 10)
         items = cache.lru_items()
@@ -376,14 +377,15 @@ class PickleCacheTestMixin:
         self.assertEqual(cache.cache_non_ghost_count, 100)
 
         cache.full_sweep()
-        gc.collect() # banish the ghosts who are no longer in the ring
+        gc.collect()  # banish the ghosts who are no longer in the ring
 
         self.assertEqual(cache.cache_non_ghost_count, 0)
 
         for oid in oids:
-            self.assertTrue(cache.get(oid) is None)
+            self.assertIsNone(cache.get(oid))
 
-    def test_full_sweep_clears_weakrefs_in_interface(self, sweep_method='full_sweep'):
+    def test_full_sweep_clears_weakrefs_in_interface(
+            self, sweep_method='full_sweep'):
         # https://github.com/zopefoundation/persistent/issues/149
         # Sweeping the cache clears weak refs (for PyPy especially)
         # In the real world, this shows up in the interaction with
@@ -424,11 +426,13 @@ class PickleCacheTestMixin:
         Interface.changed(None)
 
     def test_incrgc_clears_weakrefs_in_interface(self):
-        self.test_full_sweep_clears_weakrefs_in_interface(sweep_method='incrgc')
+        self.test_full_sweep_clears_weakrefs_in_interface(
+            sweep_method='incrgc')
 
     def test_full_sweep_clears_weakrefs(self, sweep_method='incrgc'):
         # like test_full_sweep_clears_weakrefs_in_interface,
-        # but directly using a weakref. This is the simplest version of the test.
+        # but directly using a weakref. This is the simplest version of the
+        # test.
         from weakref import ref as WeakRef
         gc.disable()
         self.addCleanup(gc.enable)
@@ -468,12 +472,12 @@ class PickleCacheTestMixin:
         self.assertEqual(cache.cache_non_ghost_count, 100)
 
         cache.minimize()
-        gc.collect() # banish the ghosts who are no longer in the ring
+        gc.collect()  # banish the ghosts who are no longer in the ring
 
         self.assertEqual(cache.cache_non_ghost_count, 0)
 
         for oid in oids:
-            self.assertTrue(cache.get(oid) is None)
+            self.assertIsNone(cache.get(oid))
 
     def test_minimize_turns_into_ghosts(self):
         from persistent.interfaces import GHOST
@@ -484,7 +488,7 @@ class PickleCacheTestMixin:
         self.assertEqual(cache.cache_non_ghost_count, 1)
 
         cache.minimize()
-        gc.collect() # banish the ghosts who are no longer in the ring
+        gc.collect()  # banish the ghosts who are no longer in the ring
 
         self.assertEqual(cache.cache_non_ghost_count, 0)
 
@@ -529,7 +533,7 @@ class PickleCacheTestMixin:
         cache = self._makeOne(jar)
         candidate = self._makePersist(oid=None, jar=None)
         cache.new_ghost(KEY, candidate)
-        self.assertTrue(cache.get(KEY) is candidate)
+        self.assertIs(cache.get(KEY), candidate)
         self.assertEqual(candidate._p_oid, KEY)
         self.assertEqual(candidate._p_jar, jar)
         self.assertEqual(candidate._p_state, GHOST)
@@ -542,43 +546,45 @@ class PickleCacheTestMixin:
         cache = self._makeOne(jar)
         candidate = self._makePersist(oid=None, jar=None, state=UPTODATE)
         cache.new_ghost(KEY, candidate)
-        self.assertTrue(cache.get(KEY) is candidate)
+        self.assertIs(cache.get(KEY), candidate)
         self.assertEqual(candidate._p_oid, KEY)
         self.assertEqual(candidate._p_jar, jar)
         self.assertEqual(candidate._p_state, GHOST)
 
     def test_new_ghost_w_pclass_non_ghost(self):
         KEY = b'123'
+
         class Pclass:
             _p_oid = None
             _p_jar = None
         cache = self._makeOne()
         cache.new_ghost(KEY, Pclass)
-        self.assertTrue(cache.get(KEY) is Pclass)
+        self.assertIs(cache.get(KEY), Pclass)
         self.assertEqual(Pclass._p_oid, KEY)
         return cache, Pclass, KEY
 
     def test_new_ghost_w_pclass_ghost(self):
         KEY = b'123'
+
         class Pclass:
             _p_oid = None
             _p_jar = None
         cache = self._makeOne()
         cache.new_ghost(KEY, Pclass)
-        self.assertTrue(cache.get(KEY) is Pclass)
+        self.assertIs(cache.get(KEY), Pclass)
         self.assertEqual(Pclass._p_oid, KEY)
         return cache, Pclass, KEY
 
     def test_invalidate_miss_single(self):
         KEY = b'123'
         cache = self._makeOne()
-        cache.invalidate(KEY) # doesn't raise
+        cache.invalidate(KEY)  # doesn't raise
 
     def test_invalidate_miss_multiple(self):
         KEY = b'123'
         KEY2 = b'456'
         cache = self._makeOne()
-        cache.invalidate([KEY, KEY2]) # doesn't raise
+        cache.invalidate([KEY, KEY2])  # doesn't raise
 
     def test_invalidate_hit_single_non_ghost(self):
         from persistent.interfaces import GHOST
@@ -614,6 +620,7 @@ class PickleCacheTestMixin:
 
     def test_debug_info_w_persistent_class(self):
         KEY = b'pclass'
+
         class pclass:
             _p_oid = KEY
             _p_jar = DummyConnection()
@@ -621,7 +628,7 @@ class PickleCacheTestMixin:
         pclass._p_state = UPTODATE
         cache[KEY] = pclass
 
-        gc.collect() # pypy vs. refcounting
+        gc.collect()  # pypy vs. refcounting
         info = cache.debug_info()
 
         self.assertEqual(len(info), 1)
@@ -641,7 +648,7 @@ class PickleCacheTestMixin:
         uptodate = self._makePersist(state=UPTODATE, oid=KEY)
         cache[KEY] = uptodate
 
-        gc.collect() # pypy vs. refcounting
+        gc.collect()  # pypy vs. refcounting
         info = cache.debug_info()
 
         self.assertEqual(len(info), 1)
@@ -653,7 +660,6 @@ class PickleCacheTestMixin:
         self.assertEqual(typ, type(uptodate).__name__)
         return uptodate, info[0]
 
-
     def test_debug_info_w_ghost(self):
         from persistent.interfaces import GHOST
 
@@ -662,7 +668,7 @@ class PickleCacheTestMixin:
         ghost = self._makePersist(state=GHOST, oid=KEY)
         cache[KEY] = ghost
 
-        gc.collect() # pypy vs. refcounting
+        gc.collect()  # pypy vs. refcounting
         info = cache.debug_info()
 
         self.assertEqual(len(info), 1)
@@ -676,8 +682,8 @@ class PickleCacheTestMixin:
 
     def test_setting_non_persistent_item(self):
         cache = self._makeOne()
-        with self.assertRaisesRegex(TypeError,
-                                    "Cache values must be persistent objects."):
+        with self.assertRaisesRegex(
+                TypeError, "Cache values must be persistent objects."):
             cache[b'12345678'] = object()
 
     def test_setting_without_jar(self):
@@ -714,15 +720,16 @@ class PickleCacheTestMixin:
 
     def test_invalidate_persistent_class_calls_p_invalidate(self):
         KEY = b'pclass'
+
         class pclass:
             _p_oid = KEY
             _p_jar = DummyConnection()
             invalidated = False
+
             @classmethod
             def _p_invalidate(cls):
                 cls.invalidated = True
 
-
         cache = self._makeOne(pclass._p_jar)
 
         cache[KEY] = pclass
@@ -758,13 +765,12 @@ class PythonPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
         cache = self._makeOne(jar)
         p = self._makePersist(jar=jar)
 
-        p._p_state = 0 # non-ghost, get in the ring
+        p._p_state = 0  # non-ghost, get in the ring
         cache[p._p_oid] = p
 
         def bad_deactivate():
             "Doesn't call super, for it's own reasons, so can't be ejected"
 
-
         p._p_deactivate = bad_deactivate
 
         cache._SWEEPABLE_TYPES = DummyPersistent
@@ -947,6 +953,7 @@ class PythonPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
 
     def test_invalidate_hit_pclass(self):
         KEY = b'123'
+
         class Pclass:
             _p_oid = KEY
             _p_jar = DummyConnection()
@@ -978,13 +985,13 @@ class PythonPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
         self.assertEqual(cache.cache_non_ghost_count, 100)
 
         cache.full_sweep()
-        gc.collect() # banish the ghosts who are no longer in the ring
+        gc.collect()  # banish the ghosts who are no longer in the ring
 
         self.assertEqual(cache.cache_non_ghost_count, 1)
 
-        self.assertTrue(cache.get(oids[0]) is not None)
+        self.assertIsNotNone(cache.get(oids[0]))
         for oid in oids[1:]:
-            self.assertTrue(cache.get(oid) is None)
+            self.assertIsNone(cache.get(oid))
 
     def test_full_sweep_w_changed(self):
         from persistent.interfaces import CHANGED
@@ -994,19 +1001,20 @@ class PythonPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
         self.assertEqual(cache.cache_non_ghost_count, 100)
 
         cache.full_sweep()
-        gc.collect() # banish the ghosts who are no longer in the ring
+        gc.collect()  # banish the ghosts who are no longer in the ring
 
         self.assertEqual(cache.cache_non_ghost_count, 1)
 
-        self.assertTrue(cache.get(oids[0]) is not None)
+        self.assertIsNotNone(cache.get(oids[0]))
         for oid in oids[1:]:
-            self.assertTrue(cache.get(oid) is None)
+            self.assertIsNone(cache.get(oid))
 
     def test_init_with_cacheless_jar(self):
         # Sometimes ZODB tests pass objects that don't
         # have a _cache
         class Jar:
             was_set = False
+
             def __setattr__(self, name, value):
                 if name == '_cache':
                     object.__setattr__(self, 'was_set', True)
@@ -1076,17 +1084,17 @@ class PythonPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
         self.assertEqual(cache.ringlen(), 1)
         items = cache.lru_items()
         self.assertEqual(items[0][0], KEY)
-        self.assertTrue(items[0][1] is candidate)
+        self.assertIs(items[0][1], candidate)
         self.assertEqual(candidate._p_state, UPTODATE)
 
     def test_cache_garbage_collection_bytes_also_deactivates_object(self):
 
         class MyPersistent(self._getDummyPersistentClass()):
             def _p_deactivate(self):
-                # mimic what the real persistent object does to update the cache
-                # size; if we don't get deactivated by sweeping, the cache size
-                # won't shrink so this also validates that _p_deactivate gets
-                # called when ejecting an object.
+                # mimic what the real persistent object does to update the
+                # cache size; if we don't get deactivated by sweeping, the
+                # cache size won't shrink so this also validates that
+                # _p_deactivate gets called when ejecting an object.
                 cache.update_object_size_estimation(self._p_oid, -1)
 
         cache = self._makeOne()
@@ -1095,9 +1103,11 @@ class PythonPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
         for i in range(100):
             oid = self._numbered_oid(i)
             oids.append(oid)
-            o = cache[oid] = self._makePersist(oid=oid, kind=MyPersistent, state=UPTODATE)
+            o = cache[oid] = self._makePersist(
+                oid=oid, kind=MyPersistent, state=UPTODATE)
 
-            o._Persistent__size = 0 # must start 0, ZODB sets it AFTER updating the size
+            # must start 0, ZODB sets it AFTER updating the size
+            o._Persistent__size = 0
 
             cache.update_object_size_estimation(oid, 64)
             o._Persistent__size = 2
@@ -1115,19 +1125,18 @@ class PythonPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
         # verify the change worked as expected
         self.assertEqual(cache.cache_size_bytes, 1)
         # verify our entrance assumption is fulfilled
-        self.assertTrue(cache.cache_size > 100)
-        self.assertTrue(cache.total_estimated_size > 1)
+        self.assertGreater(cache.cache_size, 100)
+        self.assertGreater(cache.total_estimated_size, 1)
         # A gc shrinks the bytes
         cache.incrgc()
         self.assertEqual(cache.total_estimated_size, 0)
 
         # It also shrank the measured size of the cache,
         # though this may require a GC to be visible.
-        if PYPY: # pragma: no cover
+        if PYPY:  # pragma: no cover
             gc.collect()
         self.assertEqual(len(cache), 1)
 
-
     def test_new_ghost_obj_already_in_cache(self):
         base_result = super().test_new_ghost_obj_already_in_cache()
         cache, key, candidate = base_result
@@ -1165,37 +1174,36 @@ class PythonPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
             o._Persistent__size = 0
             cache.update_object_size_estimation(oid, 1)
             o._Persistent__size = 1
-            del o # leave it only in the cache
+            del o  # leave it only in the cache
 
         self.assertEqual(cache.cache_non_ghost_count, 100)
         self.assertEqual(cache.total_estimated_size, 64 * 100)
 
         cache.incrgc()
-        gc.collect() # banish the ghosts who are no longer in the ring
+        gc.collect()  # banish the ghosts who are no longer in the ring
         self.assertEqual(cache.total_estimated_size, 64 * 6)
         self.assertEqual(cache.cache_non_ghost_count, 6)
         self.assertEqual(len(cache), 6)
 
         cache.full_sweep()
-        gc.collect() # banish the ghosts who are no longer in the ring
+        gc.collect()  # banish the ghosts who are no longer in the ring
         self.assertEqual(cache.total_estimated_size, 0)
         self.assertEqual(cache.cache_non_ghost_count, 0)
         self.assertEqual(len(cache), 0)
 
     def test_interpreter_finalization_ffi_cleanup(self):
-        # When the interpreter is busy garbage collecting old objects
-        # and clearing their __dict__ in random orders, the CFFI cleanup
-        # ``ffi.gc()`` cleanup hooks we use on CPython don't
-        # raise errors.
+        # When the interpreter is busy garbage collecting old objects and
+        # clearing their __dict__ in random orders, the CFFI cleanup
+        # ``ffi.gc()`` cleanup hooks we use on CPython don't raise errors.
         #
-        # Prior to Python 3.8, when ``sys.unraisablehook`` was added,
-        # the only way to know if this test fails is to look for AttributeError
-        # on stderr.
+        # Prior to Python 3.8, when ``sys.unraisablehook`` was added, the only
+        # way to know if this test fails is to look for AttributeError on
+        # stderr.
         #
-        # But wait, it gets worse. Prior to https://foss.heptapod.net/pypy/cffi/-/issues/492
-        # (CFFI > 1.14.5, unreleased at this writing), CFFI ignores
-        # ``sys.unraisablehook``, so even on 3.8 the only way to know
-        # a failure is to watch stderr.
+        # But wait, it gets worse. Prior to
+        # https://foss.heptapod.net/pypy/cffi/-/issues/492 (CFFI > 1.14.5,
+        # unreleased at this writing), CFFI ignores ``sys.unraisablehook``, so
+        # even on 3.8 the only way to know a failure is to watch stderr.
         #
         # See https://github.com/zopefoundation/persistent/issues/150
 
@@ -1205,13 +1213,15 @@ class PythonPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
             old_hook = sys.unraisablehook
         except AttributeError:
             pass
-        else: # pragma: no cover
+        else:  # pragma: no cover
             sys.unraisablehook = unraised.append
             self.addCleanup(setattr, sys, 'unraisablehook', old_hook)
 
         cache = self._makeOne()
         oid = self._numbered_oid(42)
-        o = cache[oid] = self._makePersist(oid=oid)
+        # local variable 'o' is assigned to but never used, but needed for the
+        # test to succeed.
+        o = cache[oid] = self._makePersist(oid=oid)  # noqa: F841
         # Clear the dict, or at least part of it.
         # This is coupled to ``cleanup_hook``
         if cache.data.cleanup_hook:
@@ -1240,9 +1250,11 @@ class CPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
     def test_inst_does_not_conform_to_IExtendedPickleCache(self):
         # Test that ``@use_c_impl`` is only applying the correct
         # interface declaration to the C implementation.
-        from persistent.interfaces import IExtendedPickleCache
-        from zope.interface.verify import verifyObject
         from zope.interface.exceptions import Invalid
+        from zope.interface.verify import verifyObject
+
+        from persistent.interfaces import IExtendedPickleCache
+
         # We don't claim to implement it.
         self.assertFalse(IExtendedPickleCache.providedBy(self._makeOne()))
         # And we don't even provide everything it asks for.
@@ -1262,7 +1274,7 @@ class CPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
                 pass
 
         dummy_connection = DummyConnection()
-        dummy_connection.register(1) # for coveralls
+        dummy_connection.register(1)  # for coveralls
 
         def makePersistent(oid):
             persist = self._getDummyPersistentClass()()
@@ -1283,7 +1295,7 @@ class CPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
             o = cache[oid] = makePersistent(oid)
             cache.update_object_size_estimation(oid, 1)
             o._p_estimated_size = 1
-            del o # leave it only in the cache
+            del o  # leave it only in the cache
 
         self.assertEqual(cache.cache_non_ghost_count, 100)
         self.assertEqual(cache.total_estimated_size, 64 * 100)
@@ -1294,7 +1306,7 @@ class CPickleCacheTests(PickleCacheTestMixin, unittest.TestCase):
         self.assertEqual(len(cache), 6)
 
         cache.full_sweep()
-        gc.collect() # banish the ghosts who are no longer in the ring
+        gc.collect()  # banish the ghosts who are no longer in the ring
         self.assertEqual(cache.total_estimated_size, 0)
         self.assertEqual(cache.cache_non_ghost_count, 0)
         self.assertEqual(len(cache), 0)
@@ -1311,8 +1323,9 @@ class TestWeakValueDictionary(unittest.TestCase):
 
     @unittest.skipIf(PYPY, "PyPy doesn't have the cleanup_hook")
     def test_cleanup_hook_gc(self):
-        # A more targeted test than ``test_interpreter_finalization_ffi_cleanup``
-        # See https://github.com/zopefoundation/persistent/issues/150
+        # A more targeted test than
+        # ``test_interpreter_finalization_ffi_cleanup`` See
+        # https://github.com/zopefoundation/persistent/issues/150
         wvd = self._makeOne()
 
         class cdata:
@@ -1327,5 +1340,6 @@ class TestWeakValueDictionary(unittest.TestCase):
 def test_suite():
     return unittest.defaultTestLoader.loadTestsFromName(__name__)
 
+
 if __name__ == '__main__':
     unittest.main()
